/*
 * This file is part of Easy Answer.
 *
 * Copyright (C) 2012 Digia Plc
 *
 * Easy Answer is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License version 2.1 as published by the Free Software Foundation.
 *
 * Easy Answer is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with Easy Answer; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301 USA
 */

import QtQuick 1.1
import com.nokia.meego 1.0
import com.nokia.extras 1.0

import "UIConstants.js" as UI

Page {
    id: page
    orientationLock: PageOrientation.LockPortrait
    tools: mainTools

    Component.onCompleted: {
        statusLabel.text = enabledSwitch.checked ? "On" : "Off";
        animationArea.state = daemonInterface.daemonState ? "enable" : "disable";
    }

    function notifyDaemonKilled(status) {
        if(!status && enabledSwitch.checked) {
            daemonKilledBanner.show();
            enabledSwitch.checked = false;
        }
    }

    InfoBanner {
        id: daemonKilledBanner
        z: 3
        timerEnabled: false
        text: "Easy Answer background process has stopped unexpectedly!"
    }

    AboutDialog {
        id: aboutDialog
    }

    Rectangle {
        id: pageHeader
        anchors.top: parent.top
        height: UI.HEADER_HEIGHT
        width: parent.width
        color: UI.HEADER_COLOR

        Label {
            id: titleLabel
            anchors.verticalCenter: parent.verticalCenter
            anchors.left: parent.left
            anchors.leftMargin: UI.DEFAULT_MARGIN
            color: UI.HEADER_FONT_COLOR
            font.family: UI.HEADER_FONT_SIZE
            font.pixelSize: UI.HEADER_FONT_SIZE
            text: "Easy Answer"
        }

        Label {
            id: statusLabel
            anchors.verticalCenter: parent.verticalCenter
            anchors.right: parent.right
            anchors.rightMargin: UI.DEFAULT_MARGIN
            color: UI.HEADER_FONT_COLOR
            font.family: UI.HEADER_FONT_SIZE
            font.pixelSize: UI.HEADER_FONT_SIZE
            text: "On"
        }

        Image {
            id: separatorImage
            anchors.bottom: parent.bottom
            width: parent.width
            source: "header-divider.png"
        }
    }

    Flickable {
        id: contentFlickable
        anchors.top: pageHeader.bottom
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: parent.bottom
        contentHeight: contentColumn.height + 2 * UI.DEFAULT_MARGIN
        flickableDirection: Flickable.VerticalFlick
        clip: true

        Column {
            id: contentColumn
            anchors {
                top: parent.top
                left: parent.left
                leftMargin: UI.DEFAULT_MARGIN
                right: parent.right
                rightMargin: UI.DEFAULT_MARGIN
            }
            spacing: UI.DEFAULT_MARGIN

            Rectangle {
                id: item
                height: enabledTitleLabel.height + enabledDescriptionLabel.height + 16
                width: parent.width
                color: "#E0E1E2"
                z: 2

                Label {
                    id: enabledTitleLabel
                    anchors.top: parent.top
                    anchors.topMargin: UI.DEFAULT_MARGIN
                    anchors.left: parent.left
                    anchors.right: enabledSwitch.left
                    text: "Activate easy answering"
                }

                Label {
                    id: enabledDescriptionLabel
                    anchors.bottom: parent.bottom
                    anchors.left: parent.left
                    anchors.right: enabledSwitch.left
                    color: UI.DISABLED_FONT_COLOR
                    wrapMode: Text.WordWrap
                    text: "Enable phone call handling with the selected gestures"
                }

                Switch {
                    id: enabledSwitch
                    anchors.verticalCenter: parent.verticalCenter
                    anchors.right: parent.right
                    checked: daemonInterface.daemonState
                    onCheckedChanged: {
                        daemonInterface.daemonState = enabledSwitch.checked;
                        statusLabel.text = enabledSwitch.checked ? "On" : "Off";
                        answerShakeGestureItem.enabled = enabledSwitch.checked;
                        answerOnEarGestureItem.enabled = enabledSwitch.checked;
                        answerPowerButtonGestureItem.enabled = enabledSwitch.checked;
                        endingPowerButtonGestureItem.enabled = enabledSwitch.checked;
                        endingShakeGestureItem.enabled = enabledSwitch.checked;
                        animationArea.state = daemonInterface.daemonState ? "enable" : "disable";
                    }
                }
            }

            Column {
                id: animationArea
                width: parent.width
                spacing: UI.DEFAULT_MARGIN
                clip: true

                GroupHeader {
                    text: "Call answering gestures"
                }

                CheckableItem {
                    id: answerOnEarGestureItem
                    checked: daemonInterface.answerOnEarGestureState
                    title: "On ear"
                    description: "Raise the phone to your ear to answer a call"
                    onClicked: {
                        daemonInterface.answerOnEarGestureState = answerOnEarGestureItem.checked;
                    }
                }

                CheckableItem {
                    id: answerPowerButtonGestureItem
                    checked: daemonInterface.answerPowerButtonGestureState
                    title: "Power button"
                    description: "Double press the power button to answer a call"
                    onClicked: {
                        daemonInterface.answerPowerButtonGestureState = answerPowerButtonGestureItem.checked;
                    }
                }

                CheckableItem {
                    id: answerShakeGestureItem
                    checked: daemonInterface.answerShakeGestureState
                    title: "Shaking"
                    description: "Shake the phone for a moment to answer a call"
                    onClicked: {
                        daemonInterface.answerShakeGestureState = answerShakeGestureItem.checked;
                    }
                }

                GroupHeader {
                    text: "Call ending gestures"
                }

                CheckableItem {
                    id: endingPowerButtonGestureItem
                    checked: daemonInterface.endPowerButtonGestureState
                    title: "Power button"
                    description: "Double press the power button to end a call"
                    onClicked: {
                        daemonInterface.endPowerButtonGestureState = endingPowerButtonGestureItem.checked;
                    }
                }

                CheckableItem {
                    id: endingShakeGestureItem
                    checked: daemonInterface.endShakeGestureState
                    title: "Shaking"
                    description: "Shake the phone for a moment to end a call"
                    onClicked: {
                        daemonInterface.endShakeGestureState = endingShakeGestureItem.checked;
                    }
                }

                states: [
                    State {
                        name: "enable"
                        PropertyChanges {
                            target: animationArea
                            y: (item.height +16)
                        }
                        PropertyChanges {
                            target: animationArea
                            opacity: 1
                        }
                    },
                    State {
                        name: "disable"
                        PropertyChanges {
                            target: animationArea
                            y: - animationArea.height
                        }
                        PropertyChanges {
                            target: animationArea
                            opacity: 0
                        }
                    }
                ]
                transitions: [
                    Transition {
                        ParallelAnimation {
                            NumberAnimation { properties:"opacity"; duration: 400 }
                            NumberAnimation { properties:"y"; duration: 500 }
                        }
                    }
                ]
            }
        }
    }

    ScrollDecorator {
        flickableItem: contentFlickable
    }

    ToolBarLayout {
        id: mainTools

        ToolIcon {
            anchors.right: parent.right
            platformIconId: "toolbar-view-menu"
            onClicked: {
                if (mainMenu.status === DialogStatus.Closed) {
                    mainMenu.open();
                } else {
                    mainMenu.close();
                }
            }
        }
    }

    Menu {
        id: mainMenu
        MenuLayout {
            MenuItem {
                text: "About";
                onClicked: {
                    aboutDialog.open();
                }
            }
            MenuItem {
                text: "Report an issue";
                onClicked: {
                    Qt.openUrlExternally("mailto:support.apps@digia.com");
                }
            }
        }
    }
}
